(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@tiptap/core')) :
  typeof define === 'function' && define.amd ? define(['exports', '@tiptap/core'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['@tiptap/extension-highlight'] = {}, global.core));
}(this, (function (exports, core) { 'use strict';

  const inputRegex = /(?:^|\s)((?:==)((?:[^~]+))(?:==))$/gm;
  const pasteRegex = /(?:^|\s)((?:==)((?:[^~]+))(?:==))/gm;
  const Highlight = core.Mark.create({
      name: 'highlight',
      defaultOptions: {
          HTMLAttributes: {},
      },
      addAttributes() {
          return {
              color: {
                  default: null,
                  parseHTML: element => {
                      return {
                          color: element.getAttribute('data-color') || element.style.backgroundColor,
                      };
                  },
                  renderHTML: attributes => {
                      if (!attributes.color) {
                          return {};
                      }
                      return {
                          'data-color': attributes.color,
                          style: `background-color: ${attributes.color}`,
                      };
                  },
              },
          };
      },
      parseHTML() {
          return [
              {
                  tag: 'mark',
              },
          ];
      },
      renderHTML({ HTMLAttributes }) {
          return ['mark', HTMLAttributes, 0];
      },
      addCommands() {
          return {
              /**
               * Set a highlight mark
               */
              setHighlight: (attributes) => ({ commands }) => {
                  return commands.setMark('highlight', attributes);
              },
              /**
               * Toggle a highlight mark
               */
              toggleHighlight: (attributes) => ({ commands }) => {
                  return commands.toggleMark('highlight', attributes);
              },
              /**
               * Unset a highlight mark
               */
              unsetHighlight: () => ({ commands }) => {
                  return commands.unsetMark('highlight');
              },
          };
      },
      addKeyboardShortcuts() {
          return {
              'Mod-e': () => this.editor.commands.toggleHighlight(),
          };
      },
      addInputRules() {
          return [
              core.markInputRule(inputRegex, this.type),
          ];
      },
      addPasteRules() {
          return [
              core.markPasteRule(inputRegex, this.type),
          ];
      },
  });

  exports.default = Highlight;
  exports.inputRegex = inputRegex;
  exports.pasteRegex = pasteRegex;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=tiptap-extension-highlight.umd.js.map
